@@ -91,7 +91,7 @@ static void show_status(int errcode)
 	if (*error)
 		fprintf(stderr, ": %s\n", error);
 	else
-		fputs(".", stderr);
+		fputs(".\n", stderr);
 	return;
 }
 
@@ -165,27 +165,29 @@ static int action_status(int arg)
 	int r;
 
 	r = crypt_query_device(&options);
+	
 	if (r < 0) {
+		/* error */
 		show_status(-r);
-		return r;
-	}
-	if (r == 0) {
+	} else if (r == 0) {
+		/* inactive */
 		printf("%s/%s is inactive.\n", crypt_get_dir(), options.name);
-		return r;
+		r = 1;
+	} else {
+		/* active */
+		printf("%s/%s is active:\n", crypt_get_dir(), options.name);
+		printf("  cipher:  %s\n", options.cipher);
+		printf("  keysize: %d bits\n", options.key_size * 8);
+		printf("  device:  %s\n", options.device);
+		printf("  offset:  %" PRIu64 " sectors\n", options.offset);
+		printf("  size:    %" PRIu64 " sectors\n", options.size);
+		if (options.skip)
+			printf("  skipped: %" PRIu64 " sectors\n", options.skip);
+		printf("  mode:    %s\n", (options.flags & CRYPT_FLAG_READONLY)
+		                           ? "readonly" : "read/write");
+		crypt_put_options(&options);
+		r = 0;
 	}
-
-	printf("%s/%s is active:\n", crypt_get_dir(), options.name);
-	printf("  cipher:  %s\n", options.cipher);
-	printf("  keysize: %d bits\n", options.key_size * 8);
-	printf("  device:  %s\n", options.device);
-	printf("  offset:  %" PRIu64 " sectors\n", options.offset);
-	printf("  size:    %" PRIu64 " sectors\n", options.size);
-	if (options.skip)
-		printf("  skipped: %" PRIu64 " sectors\n", options.skip);
-	printf("  mode:    %s\n", (options.flags & CRYPT_FLAG_READONLY)
-	                           ? "readonly" : "read/write");
-
-	crypt_put_options(&options);
 	return r;
 }
 
@@ -194,7 +196,7 @@ static int yesDialog(char *msg)
 	int r = 0;
 	if(isatty(0) && !opt_batch_mode) {
 		char *answer=NULL;
-		int size=0;
+	        size_t size=0;
 		fprintf(stderr,"\nWARNING!\n========\n");
 		fprintf(stderr,"%s\n\nAre you sure? (Type uppercase yes): ",msg);
 		getline(&answer,&size,stdin);
@@ -256,6 +258,9 @@ static int action_luksDelKey(int arg)
 	struct crypt_options options = {
 		.device = action_argv[0],
 		.key_slot = atoi(action_argv[1]),
+		.key_file = opt_key_file,
+		.timeout = opt_timeout,
+		.flags = !opt_batch_mode?CRYPT_FLAG_VERIFY_ON_DELKEY : 0,
 	};
 	int r; 
 
@@ -274,7 +279,6 @@ static int action_luksAddKey(int arg)
 {
 	struct crypt_options options = {
 		.device = action_argv[0],
-		.key_file = opt_key_file,
 		.new_key_file = action_argc>1?action_argv[1]:NULL,
 		.key_file = opt_key_file,
 		.flags = opt_verify_passphrase ? CRYPT_FLAG_VERIFY : (!opt_batch_mode?CRYPT_FLAG_VERIFY_IF_POSSIBLE : 0),
